// Copyright Epic Games, Inc. All Rights Reserved.

#include "StaticMeshUtilitiesBPLibrary.h"
#include "StaticMeshUtilities.h"
#include "Engine/StaticMeshSocket.h"

UStaticMeshUtilitiesBPLibrary::UStaticMeshUtilitiesBPLibrary(const FObjectInitializer& ObjectInitializer)
	: Super(ObjectInitializer)
{
}

void UStaticMeshUtilitiesBPLibrary::CopySocketsFromStaticMesh(UStaticMesh* CopyFrom, UStaticMesh* CopyTo, const bool bDeleteExistingSockets)
{
#if WITH_EDITOR
	if (CopyFrom != nullptr && CopyTo != nullptr && CopyFrom != CopyTo)
	{
		if (CopyFrom->Sockets.Num() > 0)
		{
			CopyTo->PreEditChange(NULL);
			if (bDeleteExistingSockets)
			{
				CopyTo->Sockets.Empty();
			}
			for (int32 i = 0; i < CopyFrom->Sockets.Num(); i++)
			{
				auto Sock = CopyFrom->Sockets[i];

				UStaticMeshSocket* NewSocket = NewObject<UStaticMeshSocket>(CopyTo);
				NewSocket->SocketName = Sock->SocketName;
				NewSocket->SetFlags(RF_Transactional);
				NewSocket->RelativeLocation = Sock->RelativeLocation;
				NewSocket->RelativeRotation = Sock->RelativeRotation;
				NewSocket->RelativeScale = Sock->RelativeScale;
				NewSocket->Tag = Sock->Tag;
				CopyTo->Sockets.Add(NewSocket);
			}
			CopyTo->PostEditChange();
			CopyTo->MarkPackageDirty();
		}
	}
#endif
}

void UStaticMeshUtilitiesBPLibrary::DeleteAllSocketsFromStaticMesh(UStaticMesh* StaticMesh)
{
#if WITH_EDITOR
	if (StaticMesh != nullptr)
	{
		StaticMesh->PreEditChange(NULL);
		StaticMesh->Sockets.Empty();
		StaticMesh->PostEditChange();
		StaticMesh->MarkPackageDirty();
	}
#endif
}

void UStaticMeshUtilitiesBPLibrary::CreateMultipleMeshSockets(UStaticMesh* StaticMesh, int32 NumberOfSockets, bool bDeleteExistingSockets, FName SocketPrefix, FVector SocketOffset, FRotator SocketRotation)
{
#if WITH_EDITOR
	if (StaticMesh != nullptr && NumberOfSockets > 0)
	{
		StaticMesh->PreEditChange(NULL);
		if (bDeleteExistingSockets)
		{
			StaticMesh->Sockets.Empty();
		}
		for (int32 i = 0; i < NumberOfSockets; i++)
		{
			UStaticMeshSocket* NewSocket = NewObject<UStaticMeshSocket>(StaticMesh);
			FString SocketNumber = (i < 10) ? "0" + FString::FromInt(i) : FString::FromInt(i);
			FString SocketName = SocketPrefix.ToString() + "_" + SocketNumber;
			NewSocket->SocketName = FName(*(SocketPrefix.ToString() + "_" + SocketNumber));
			NewSocket->SetFlags(RF_Transactional);
			NewSocket->RelativeLocation = SocketOffset*i;
			NewSocket->RelativeRotation = SocketRotation*i;
			NewSocket->RelativeScale = FVector(1, 1, 1);
			StaticMesh->Sockets.Add(NewSocket);
		}
		StaticMesh->PostEditChange();
		StaticMesh->MarkPackageDirty();
	}
#endif
}