// Copyright Epic Games, Inc. All Rights Reserved.

#pragma once

#include "Kismet/BlueprintFunctionLibrary.h"
#include "StaticMeshUtilitiesBPLibrary.generated.h"

/*
*	Function library class.
*	Each function in it is expected to be static and represents blueprint node that can be called in any blueprint.
*
*	When declaring function you can define metadata for the node. Key function specifiers will be BlueprintPure and BlueprintCallable.
*	BlueprintPure - means the function does not affect the owning object in any way and thus creates a node without Exec pins.
*	BlueprintCallable - makes a function which can be executed in Blueprints - Thus it has Exec pins.
*	DisplayName - full name of the node, shown when you mouse over the node and in the blueprint drop down menu.
*				Its lets you name the node using characters not allowed in C++ function names.
*	CompactNodeTitle - the word(s) that appear on the node.
*	Keywords -	the list of keywords that helps you to find node when you search for it using Blueprint drop-down menu.
*				Good example is "Print String" node which you can find also by using keyword "log".
*	Category -	the category your node will be under in the Blueprint drop-down menu.
*
*	For more info on custom blueprint nodes visit documentation:
*	https://wiki.unrealengine.com/Custom_Blueprint_Node_Creation
*/
UCLASS()
class UStaticMeshUtilitiesBPLibrary : public UBlueprintFunctionLibrary
{
	GENERATED_UCLASS_BODY()

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "Copy Sockets From Static Mesh", Keywords = "StaticMeshUtilities Sockets"), Category = "StaticMeshUtilities|Sockets")
	static void CopySocketsFromStaticMesh(class UStaticMesh *CopyFrom, class UStaticMesh *CopyTo, bool bDeleteExistingSockets = true);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "Delete all Static Mesh sockets", Keywords = "StaticMeshUtilities Sockets"), Category = "StaticMeshUtilities|Sockets")
	static void DeleteAllSocketsFromStaticMesh(class UStaticMesh *StaticMesh);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "Create Multiple Mesh sockets", Keywords = "StaticMeshUtilities Sockets"), Category = "StaticMeshUtilities|Sockets")
	static void CreateMultipleMeshSockets(class UStaticMesh *StaticMesh, int32 NumberOfSockets, bool bDeleteExistingSockets = true, FName SocketPrefix = "Socket_", FVector SocketOffset = FVector(0, 0, 0), FRotator SocketRotation = FRotator(0, 0, 0));
};